@@ -51,6 +51,8 @@ __all__ = (
     "DeleteRequestTypeDef",
     "DeleteTypeDef",
     "EndpointTypeDef",
+    "ExportDescriptionTypeDef",
+    "ExportSummaryTypeDef",
     "FailureExceptionTypeDef",
     "GetTypeDef",
     "GlobalSecondaryIndexDescriptionTypeDef",
@@ -109,6 +111,7 @@ __all__ = (
     "DescribeContinuousBackupsOutputTypeDef",
     "DescribeContributorInsightsOutputTypeDef",
     "DescribeEndpointsResponseTypeDef",
+    "DescribeExportOutputTypeDef",
     "DescribeGlobalTableOutputTypeDef",
     "DescribeGlobalTableSettingsOutputTypeDef",
     "DescribeLimitsOutputTypeDef",
@@ -116,6 +119,7 @@ __all__ = (
     "DescribeTableReplicaAutoScalingOutputTypeDef",
     "DescribeTimeToLiveOutputTypeDef",
     "ExpectedAttributeValueTypeDef",
+    "ExportTableToPointInTimeOutputTypeDef",
     "GetItemOutputTypeDef",
     "GlobalSecondaryIndexAutoScalingUpdateTypeDef",
     "GlobalSecondaryIndexTypeDef",
@@ -123,6 +127,7 @@ __all__ = (
     "GlobalTableGlobalSecondaryIndexSettingsUpdateTypeDef",
     "ListBackupsOutputTypeDef",
     "ListContributorInsightsOutputTypeDef",
+    "ListExportsOutputTypeDef",
     "ListGlobalTablesOutputTypeDef",
     "ListTablesOutputTypeDef",
     "ListTagsOfResourceOutputTypeDef",
@@ -556,6 +561,38 @@ class DeleteTypeDef(_RequiredDeleteTypeDef, _OptionalDeleteTypeDef):
 
 EndpointTypeDef = TypedDict("EndpointTypeDef", {"Address": str, "CachePeriodInMinutes": int})
 
+ExportDescriptionTypeDef = TypedDict(
+    "ExportDescriptionTypeDef",
+    {
+        "ExportArn": str,
+        "ExportStatus": Literal["IN_PROGRESS", "COMPLETED", "FAILED"],
+        "StartTime": datetime,
+        "EndTime": datetime,
+        "ExportManifest": str,
+        "TableArn": str,
+        "TableId": str,
+        "ExportTime": datetime,
+        "ClientToken": str,
+        "S3Bucket": str,
+        "S3BucketOwner": str,
+        "S3Prefix": str,
+        "S3SseAlgorithm": Literal["AES256", "KMS"],
+        "S3SseKmsKeyId": str,
+        "FailureCode": str,
+        "FailureMessage": str,
+        "ExportFormat": Literal["DYNAMODB_JSON", "ION"],
+        "BilledSizeBytes": int,
+        "ItemCount": int,
+    },
+    total=False,
+)
+
+ExportSummaryTypeDef = TypedDict(
+    "ExportSummaryTypeDef",
+    {"ExportArn": str, "ExportStatus": Literal["IN_PROGRESS", "COMPLETED", "FAILED"]},
+    total=False,
+)
+
 FailureExceptionTypeDef = TypedDict(
     "FailureExceptionTypeDef", {"ExceptionName": str, "ExceptionDescription": str}, total=False
 )
@@ -1516,6 +1553,12 @@ DescribeEndpointsResponseTypeDef = TypedDict(
     "DescribeEndpointsResponseTypeDef", {"Endpoints": List["EndpointTypeDef"]}
 )
 
+DescribeExportOutputTypeDef = TypedDict(
+    "DescribeExportOutputTypeDef",
+    {"ExportDescription": "ExportDescriptionTypeDef", "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
+
 DescribeGlobalTableOutputTypeDef = TypedDict(
     "DescribeGlobalTableOutputTypeDef",
     {
@@ -1628,6 +1671,12 @@ ExpectedAttributeValueTypeDef = TypedDict(
     total=False,
 )
 
+ExportTableToPointInTimeOutputTypeDef = TypedDict(
+    "ExportTableToPointInTimeOutputTypeDef",
+    {"ExportDescription": "ExportDescriptionTypeDef", "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
+
 GetItemOutputTypeDef = TypedDict(
     "GetItemOutputTypeDef",
     {
@@ -1736,6 +1785,16 @@ ListContributorInsightsOutputTypeDef = TypedDict(
     total=False,
 )
 
+ListExportsOutputTypeDef = TypedDict(
+    "ListExportsOutputTypeDef",
+    {
+        "ExportSummaries": List["ExportSummaryTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadata",
+    },
+    total=False,
+)
+
 ListGlobalTablesOutputTypeDef = TypedDict(
     "ListGlobalTablesOutputTypeDef",
     {
